@@ -143,7 +143,7 @@ INVALIDCLIENTTOKEN_TOOLONG = 'InvalidClientToken.TooLong'
 # 无效的过滤器。
 INVALIDFILTER = 'InvalidFilter'
 
-# [`Filter`](/document/api/213/15753#Filter)。
+# [`Filter`](/document/api/213/15753#Filter)传值超出限制。
 INVALIDFILTERVALUE_LIMITEXCEEDED = 'InvalidFilterValue.LimitExceeded'
 
 # 不支持该宿主机实例执行指定的操作。
@@ -392,6 +392,15 @@ INVALIDPARAMETERVALUE_DUPLICATE = 'InvalidParameterValue.Duplicate'
 # 重复标签。
 INVALIDPARAMETERVALUE_DUPLICATETAGS = 'InvalidParameterValue.DuplicateTags'
 
+# 弹性网卡数据不存在
+INVALIDPARAMETERVALUE_ELASTICNETWORKNOTEXIST = 'InvalidParameterValue.ElasticNetworkNotExist'
+
+# 弹性网卡数据vpc子网不匹配,必须为同vpc不同子网
+INVALIDPARAMETERVALUE_ELASTICNETWORKVPCSUBNETMISMATCH = 'InvalidParameterValue.ElasticNetworkVpcSubnetMismatch'
+
+# 弹性网卡ID不合要求，请提供规范的弹性网卡ID，类似eni-xxxxxxxx，字母x代表小写字符或者数字
+INVALIDPARAMETERVALUE_ENIIDMALFORMED = 'InvalidParameterValue.EniIdMalformed'
+
 # 实例的申请的外网IP个数超过了这种规格实例的外网ip配额。
 INVALIDPARAMETERVALUE_EXTERNALIPQUOTALIMITED = 'InvalidParameterValue.ExternalIpQuotaLimited'
 
@@ -425,6 +434,9 @@ INVALIDPARAMETERVALUE_INSTANCENOTSUPPORTEDMIXPRICINGMODEL = 'InvalidParameterVal
 # 指定机型不存在
 INVALIDPARAMETERVALUE_INSTANCETYPENOTFOUND = 'InvalidParameterValue.InstanceTypeNotFound'
 
+# 实例类型不支持弹性网卡数据
+INVALIDPARAMETERVALUE_INSTANCETYPENOTSUPPORTELASTICNETWORKS = 'InvalidParameterValue.InstanceTypeNotSupportElasticNetworks'
+
 # 实例类型不可加入高性能计算集群。
 INVALIDPARAMETERVALUE_INSTANCETYPENOTSUPPORTHPCCLUSTER = 'InvalidParameterValue.InstanceTypeNotSupportHpcCluster'
 
@@ -557,6 +569,9 @@ INVALIDPARAMETERVALUE_LOCALDISKSIZERANGE = 'InvalidParameterValue.LocalDiskSizeR
 # 参数值必须为开启DHCP的VPC
 INVALIDPARAMETERVALUE_MUSTDHCPENABLEDVPC = 'InvalidParameterValue.MustDhcpEnabledVpc'
 
+# 参数值必须为开启弹性rdma接口
+INVALIDPARAMETERVALUE_MUSTENABLEDISRDMA = 'InvalidParameterValue.MustEnabledIsRdma'
+
 # 子网不属于该cdc集群。
 INVALIDPARAMETERVALUE_NOTCDCSUBNET = 'InvalidParameterValue.NotCdcSubnet'
 
@@ -587,6 +602,9 @@ INVALIDPARAMETERVALUE_SNAPSHOTIDMALFORMED = 'InvalidParameterValue.SnapshotIdMal
 # 子网ID不合要求，请提供规范的子网ID，类似subnet-xxxxxxxx，字母x代表小写字符或者数字
 INVALIDPARAMETERVALUE_SUBNETIDMALFORMED = 'InvalidParameterValue.SubnetIdMalformed'
 
+# 子网ID所在可用区与实例所在区不匹配。
+INVALIDPARAMETERVALUE_SUBNETIDZONEIDNOTMATCH = 'InvalidParameterValue.SubnetIdZoneIdNotMatch'
+
 # 创建失败，您指定的子网不存在，请您重新指定
 INVALIDPARAMETERVALUE_SUBNETNOTEXIST = 'InvalidParameterValue.SubnetNotExist'
 
@@ -875,6 +893,9 @@ UNSUPPORTEDOPERATION_BANDWIDTHPACKAGEIDNOTSUPPORTED = 'UnsupportedOperation.Band
 # cbs远端ssd盘不支持该操作
 UNSUPPORTEDOPERATION_CBSREMOTESSDNOTSUPPORT = 'UnsupportedOperation.CbsRemoteSsdNotSupport'
 
+# 实例使用商业镜像暂不支持调整付费模式。
+UNSUPPORTEDOPERATION_COMMERCIALIMAGECHANGECHARGETYPE = 'UnsupportedOperation.CommercialImageChangeChargeType'
+
 # 实例创建快照的时间距今不到24小时。
 UNSUPPORTEDOPERATION_DISKSNAPCREATETIMETOOOLD = 'UnsupportedOperation.DiskSnapCreateTimeTooOld'
 
